#!/usr/bin/perl

@items = <STDIN>;

#---------------------------------------------------------------------
#
# getallresults ($skip)
#
# grabs $searchurl$searchterm from ebay, and infinitely recurses to find
#   all hits of a particular item (50 at a time is max eBay threshold)
#
# returns an array with all the eBay hits for $searchurl$searchterm
# 
#---------------------------------------------------------------------

sub getallresults ($$) {

#run lynx getting output for each search term in the data.

     my ($urlterm, $skip) = @_;  #get parameter

     my $skipnums = $skip *50;
# set up recursion of searches that exceed the eBay display threshold

     my @result=`lynx --source "$searchurl$urlterm\&skip\=$skipnums" 2> /dev/null`;
     my @append;

# limit recursion to predefined value of $maxdepth
     if ($skip >= $maxdepth) { return @result; };

# find the "Next button" on the page, and recurse if it's there
     if (grep /\<input.*Next\"\>/i, @result) {

# this code runs if there is a "Next" button on the page we snarfed
       $skip+=1;
       @append=getallresults($urlterm, $skip);

     }

# if this is the end of the recusion, return what we got
     else { return @result; }

# but if we recursed, return the result of the recursion added to what
# we already have
     return (@result, @append);
 
 }

#---------------------------------------------------------------------



#---------------------------------------------------------------------
#
# main program begins
#
#---------------------------------------------------------------------

#---------------------------------------------------------------------
#define searchurl to be whatever you'd like it to be.  the default turns up
#items sorted newly-listed first.
#---------------------------------------------------------------------

$searchurl='http://search.ebay.com/search/search.dll?MfcISAPICommand=GetResult&ht=1&SortProperty=MetaNewSort&query=';

#---------------------------------------------------------------------
#define maximum recursion level (this * 50 = number of items)
#goes to 500 items max by default
#if you set it to more, you might run out of memory eventually
#--------------------------------------------------------------------

$maxdepth=10;

#---------------------------------------------------------------------
# start the output
#---------------------------------------------------------------------
$date = `date +"%D at %T"`;
chop $date;

print <<HEADER;
<html>
<head>
<title>eBay Search Results</title>
</head>

<body>
<h2>Results of your eBay autosearch on $date</h2>

<h3>Index of individual searches</h3>
<p><ul>
HEADER

foreach $searchterm (@items) {

#kill trailing newline on each searchterm
      chop $searchterm;

      my $urlterm = $searchterm;
#replace spaces in searchterm with %20 for URL compatibility
      $urlterm=~s/ /%20/g;
  
  if (length($searchterm) > 2) {
      print "<li><a href=\"#$urlterm\">$searchterm</a>\n"; }

  }

print "</ul>\n";
print "<hr><h3>Results of individual searches</h3>\n";

#---------------------------------------------------------------------
# run each input term through ebay's search
#---------------------------------------------------------------------
foreach $searchterm (@items)

{

#assume if length < 2 that it's a divider and don't process it

#the following code only runs if we're not dealing with a divider
#in the particular $searchterm that we are looking at

  if (length($searchterm) > 2)

    {

     my $urlterm = $searchterm;

#replace spaces in searchterm with %20 for URL compatibility
     $urlterm=~s/ /%20/g;

#print index reference
     print "<a name=\"$urlterm\"></a>\n";

     print "<h3>eBay Matches for \"$searchterm\"</h3>\n<p><table>";

#go get all the results for the current search term, starting at threshold 0
     @result=getallresults($urlterm, 0);

#narrow down the masses of html some, all items have ViewItem in the URL
     @result=grep /ViewItem/i, @result;

#cut out all ebay-related cruft that would sod up the search results
     @result=grep !/search\.dll/, @result;
     @result=grep !/\#DESC/, @result;
     @result=grep !/alt=BuyItNow/, @result;
     @result=grep !/alt=\"BuyItNow\"/, @result;
     @result=grep !/alt=\"Pic\"/, @result;
     @result=grep !/alt=\"\[Picture!\]\"/, @result;
     @result=grep !/thumbs.ebay.com/, @result;

#filter only lines with links to items in them
     @result=grep /\<a\shref.*\<\/a\>/i, @result;

#construct output html lines    
     foreach $blah (@result) {

#print item number
	$blah=~/item\=([0-9]*)/i;
        print "<tr><td style=\"text-align: right\">eBay Item# $1 - </td>";

#print link
 	$blah=~/(\<a\shref.*\<\/a\>)/i;
	print "<td style=\"text-align: left\">$1</td></tr>";

#newline to clean up the code
        print "\n";

	}

  }
  print "</table>\n\n";

}
print <<FOOTER;

<hr>
<p>Visit <a href="http://cgi1.ebay.com/aw-cgi/eBayISAPI.dll?MyEbayLogin">My eBay</a>.
<hr>
<p>eBay Search v0.14,
<p>Click here for the <a href="readme.html">documentation</a>.

<a href="mailto:nemesis\@icequake.net">nemesis\@icequake.net</a>

</body>
</html>
FOOTER

exit;

